==> dateparser_0.7.2.orig.tar.gz: dateparser-0.7.2/dateparser/data/date_translation_data/gl.py <==
# -*- coding: utf-8 -*-
info = {
    "name": "gl",
    "date_order": "DMY",
    "january": [
        "xaneiro",
        "xan"
    ],
    "february": [
        "febreiro",
        "feb"
    ],
    "march": [
        "marzo",
        "mar"
    ],
    "april": [
        "abril",
        "abr"
    ],
    "may": [
        "maio"
    ],
    "june": [
        "xuño"
    ],
    "july": [
        "xullo",
        "xul"
    ],
    "august": [
        "agosto",
        "ago"
    ],
    "september": [
        "setembro",
        "set"
    ],
    "october": [
        "outubro",
        "out"
    ],
    "november": [
        "novembro",
        "nov"
    ],
    "december": [
        "decembro",
        "dec"
    ],
    "monday": [
        "luns"
    ],
    "tuesday": [
        "martes",
        "mar"
    ],
    "wednesday": [
        "mércores",
        "mér"
    ],
    "thursday": [
        "xoves",
        "xov"
    ],
    "friday": [
        "venres",
        "ven"
    ],
    "saturday": [
        "sábado",
        "sáb"
    ],
    "sunday": [
        "domingo",
        "dom"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "ano",
        "a"
    ],
    "month": [
        "mes",
        "m"
    ],
    "week": [
        "semana",
        "sem"
    ],
    "day": [
        "día",
        "d"
    ],
    "hour": [
        "hora",
        "h"
    ],
    "minute": [
        "minuto",
        "min"
    ],
    "second": [
        "segundo",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "o ano pasado",
            "ano pasado"
        ],
        "0 year ago": [
            "este ano"
        ],
        "in 1 year": [
            "o próximo ano",
            "seguinte ano"
        ],
        "1 month ago": [
            "o mes pasado",
            "m pasado"
        ],
        "0 month ago": [
            "este mes",
            "este m"
        ],
        "in 1 month": [
            "o próximo mes",
            "m seguinte"
        ],
        "1 week ago": [
            "a semana pasada",
            "sem pasada"
        ],
        "0 week ago": [
            "esta semana",
            "esta sem"
        ],
        "in 1 week": [
            "a próxima semana",
            "sem seguinte"
        ],
        "1 day ago": [
            "onte"
        ],
        "0 day ago": [
            "hoxe"
        ],
        "in 1 day": [
            "mañá"
        ],
        "0 hour ago": [
            "nesta hora"
        ],
        "0 minute ago": [
            "neste minuto"
        ],
        "0 second ago": [
            "agora"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "en (\\d+) ano",
            "en (\\d+) anos",
            "en (\\d+) a"
        ],
        "\\1 year ago": [
            "hai (\\d+) ano",
            "hai (\\d+) anos",
            "hai (\\d+) a"
        ],
        "in \\1 month": [
            "en (\\d+) mes",
            "en (\\d+) meses",
            "en (\\d+) m"
        ],
        "\\1 month ago": [
            "hai (\\d+) mes",
            "hai (\\d+) meses",
            "hai (\\d+) m"
        ],
        "in \\1 week": [
            "en (\\d+) semana",
            "en (\\d+) semanas",
            "en (\\d+) sem"
        ],
        "\\1 week ago": [
            "hai (\\d+) semana",
            "hai (\\d+) semanas",
            "hai (\\d+) sem"
        ],
        "in \\1 day": [
            "en (\\d+) día",
            "en (\\d+) días",
            "en (\\d+) d"
        ],
        "\\1 day ago": [
            "hai (\\d+) día",
            "hai (\\d+) días",
            "hai (\\d+) d"
        ],
        "in \\1 hour": [
            "en (\\d+) hora",
            "en (\\d+) horas",
            "en (\\d+) h"
        ],
        "\\1 hour ago": [
            "hai (\\d+) hora",
            "hai (\\d+) horas",
            "hai (\\d+) h"
        ],
        "in \\1 minute": [
            "en (\\d+) minuto",
            "en (\\d+) minutos",
            "en (\\d+) min"
        ],
        "\\1 minute ago": [
            "hai (\\d+) minuto",
            "hai (\\d+) minutos",
            "hai (\\d+) min"
        ],
        "in \\1 second": [
            "en (\\d+) segundo",
            "en (\\d+) segundos",
            "en (\\d+) s"
        ],
        "\\1 second ago": [
            "hai (\\d+) segundo",
            "hai (\\d+) segundos",
            "hai (\\d+) s"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> dateparser_1.1.0.orig.tar.gz: dateparser-1.1.0/dateparser/data/date_translation_data/gl.py <==
info = {
    "name": "gl",
    "date_order": "DMY",
    "january": [
        "xan",
        "xaneiro"
    ],
    "february": [
        "feb",
        "febreiro"
    ],
    "march": [
        "mar",
        "marzo"
    ],
    "april": [
        "abr",
        "abril"
    ],
    "may": [
        "maio"
    ],
    "june": [
        "xuño"
    ],
    "july": [
        "xul",
        "xullo"
    ],
    "august": [
        "ago",
        "agosto"
    ],
    "september": [
        "set",
        "setembro"
    ],
    "october": [
        "out",
        "outubro"
    ],
    "november": [
        "nov",
        "novembro"
    ],
    "december": [
        "dec",
        "decembro"
    ],
    "monday": [
        "luns"
    ],
    "tuesday": [
        "mar",
        "martes"
    ],
    "wednesday": [
        "mér",
        "mércores"
    ],
    "thursday": [
        "xov",
        "xoves"
    ],
    "friday": [
        "ven",
        "venres"
    ],
    "saturday": [
        "sáb",
        "sábado"
    ],
    "sunday": [
        "dom",
        "domingo"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "a",
        "ano"
    ],
    "month": [
        "m",
        "mes"
    ],
    "week": [
        "sem",
        "semana"
    ],
    "day": [
        "d",
        "día"
    ],
    "hour": [
        "h",
        "hora"
    ],
    "minute": [
        "min",
        "minuto"
    ],
    "second": [
        "s",
        "segundo"
    ],
    "relative-type": {
        "0 day ago": [
            "hoxe"
        ],
        "0 hour ago": [
            "nesta hora"
        ],
        "0 minute ago": [
            "neste minuto"
        ],
        "0 month ago": [
            "este m",
            "este mes"
        ],
        "0 second ago": [
            "agora"
        ],
        "0 week ago": [
            "esta sem",
            "esta semana"
        ],
        "0 year ago": [
            "este ano"
        ],
        "1 day ago": [
            "onte"
        ],
        "1 month ago": [
            "m pasado",
            "o mes pasado"
        ],
        "1 week ago": [
            "a semana pasada",
            "sem pasada"
        ],
        "1 year ago": [
            "ano pasado",
            "o ano pasado"
        ],
        "in 1 day": [
            "mañá"
        ],
        "in 1 month": [
            "m seguinte",
            "o próximo mes"
        ],
        "in 1 week": [
            "a próxima semana",
            "sem seguinte"
        ],
        "in 1 year": [
            "o próximo ano",
            "seguinte ano"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "hai (\\d+) d",
            "hai (\\d+) día",
            "hai (\\d+) días"
        ],
        "\\1 hour ago": [
            "hai (\\d+) h",
            "hai (\\d+) hora",
            "hai (\\d+) horas"
        ],
        "\\1 minute ago": [
            "hai (\\d+) min",
            "hai (\\d+) minuto",
            "hai (\\d+) minutos"
        ],
        "\\1 month ago": [
            "hai (\\d+) m",
            "hai (\\d+) mes",
            "hai (\\d+) meses"
        ],
        "\\1 second ago": [
            "hai (\\d+) s",
            "hai (\\d+) segundo",
            "hai (\\d+) segundos"
        ],
        "\\1 week ago": [
            "hai (\\d+) sem",
            "hai (\\d+) semana",
            "hai (\\d+) semanas"
        ],
        "\\1 year ago": [
            "hai (\\d+) a",
            "hai (\\d+) ano",
            "hai (\\d+) anos"
        ],
        "in \\1 day": [
            "en (\\d+) d",
            "en (\\d+) día",
            "en (\\d+) días"
        ],
        "in \\1 hour": [
            "en (\\d+) h",
            "en (\\d+) hora",
            "en (\\d+) horas"
        ],
        "in \\1 minute": [
            "en (\\d+) min",
            "en (\\d+) minuto",
            "en (\\d+) minutos"
        ],
        "in \\1 month": [
            "en (\\d+) m",
            "en (\\d+) mes",
            "en (\\d+) meses"
        ],
        "in \\1 second": [
            "en (\\d+) s",
            "en (\\d+) segundo",
            "en (\\d+) segundos"
        ],
        "in \\1 week": [
            "en (\\d+) sem",
            "en (\\d+) semana",
            "en (\\d+) semanas"
        ],
        "in \\1 year": [
            "en (\\d+) a",
            "en (\\d+) ano",
            "en (\\d+) anos"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
